@@ -255,6 +255,7 @@ def overrideLintian() -> None:
                      'sharedobject-in-library-directory-missing-soname',  # upstream issue
                      'shared-library-lacks-version',  # upstream issue
                      'spelling-error-in-binary',  # upstream issue
+                     'specific-address-in-shared-library',  # upstream issue
                      'unstripped-binary-or-object',  # stripping not allowed
                      'exit-in-shared-library',  # upstream issue
                      'lacks-ldconfig-trigger',  # follows from sharedobject-in-library-directory-missing-soname
@@ -340,5 +341,5 @@ if __name__ == '__main__':
     #  - the shell scripts for compiler variables are ignored. They are
     #    somewhat useless if we don't retain upstream directory structure.
 
-    # do the lintian overridding
+    # do the lintian overriding
     overrideLintian()
